<?php

/* login/footer.twig */
class __TwigTemplate_336bd283204be05181d91eb24d58531baab61b9ed61cc6d0d39490c1b3d45ab3 extends Twig_Template
{
    public function __construct(Twig_Environment $env)
    {
        parent::__construct($env);

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = [])
    {
        // line 1
        echo "</div>
";
    }

    public function getTemplateName()
    {
        return "login/footer.twig";
    }

    public function getDebugInfo()
    {
        return array (  19 => 1,);
    }

    /** @deprecated since 1.27 (to be removed in 2.0). Use getSourceContext() instead */
    public function getSource()
    {
        @trigger_error('The '.__METHOD__.' method is deprecated since version 1.27 and will be removed in 2.0. Use getSourceContext() instead.', E_USER_DEPRECATED);

        return $this->getSourceContext()->getCode();
    }

    public function getSourceContext()
    {
        return new Twig_Source("", "login/footer.twig", "/usr/local/cpanel/base/3rdparty/phpMyAdmin/templates/login/footer.twig");
    }
}
